/**
 * Content component
 */
import React, { Fragment, useEffect, useRef, useState, useCallback } from 'react';
import { Toast } from '@bryntum/schedulerpro';
import { BryntumSchedulerPro, BryntumButton } from '@bryntum/schedulerpro-react';
import TaskStore from '../lib/TaskStore.js';

import { Tooltip } from '@bryntum/schedulerpro';
import UnplannedGridComponent from '../components/UnplannedGrid.js';
import Drag from '../lib/Drag.js';

import { schedulerConfig } from './ContentConfig.js';

const Content = props => {
    // we need there refs for setting up dragging
    const scheduler = useRef(null);
    const grid = useRef(null);

    const [autoReschedule, setAutoReschedule] = useState(false);

    // event store is needed by both scheduler and grid
    // so we create it before to be accessible by both
    const [eventStore] = useState(new TaskStore());
    const resources =             [{
        "id"   : 1,
        "name" : "Arcady",
        "role" : "Core developer"
    },
    {
        "id"   : 2,
        "name" : "Dave",
        "role" : "Tech Sales"
    },
    {
        "id"   : 3,
        "name" : "Henrik",
        "role" : "Sales"
    },
    {
        "id"   : 4,
        "name" : "Linda",
        "role" : "Core developer"
    }]
const [events, setEvents] =  useState([
    {
        "id"           : "r1",
        "resourceId"   : 1,
        "name"         : "Restart server",
        "iconCls"      : "b-fa b-fa-sync",
        "startDate"    : "2026-01-01T08:00:00",
        "duration"     : 3,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": '',
    },
    {
        "id"           : "r2",
        "resourceId"   : 1,
        "name"         : "Upgrade memory",
        "iconCls"      : "b-fa b-fa-laptop",
        "startDate"    : "2025-12-01T15:00:00",
        "cls"          : "",
        "duration"     : 3,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    },
    {
        "id"           : "r3",
        "resourceId"   : 2,
        "name"         : "Visit customer",
        "iconCls"      : "b-fa b-fa-user",
        "startDate"    : "2025-12-01T09:00:00",
        "cls"          : "",
        "duration"     : 3,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    },
    {
        "id"           : "r4",
        "resourceId"   : 3,
        "name"         : "Arrange meetup",
        "iconCls"      : "b-fa b-fa-users",
        "startDate"    : "2025-12-01T09:00:00",
        "cls"          : "",
        "duration"     : 3,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    },
    {
        "id"           : "r5",
        "resourceId"   : 7,
        "name"         : "Make coffee",
        "startDate"    : "2025-12-01T12:00:00",
        "iconCls"      : "b-fa b-fa-coffee",
        "duration"     : 4,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    },
    {
        "id"           : "r6",
        "resourceId"   : 9,
        "name"         : "Conference prep",
        "iconCls"      : "b-fa b-fa-building",
        "startDate"    : "2026-01-01T09:00:00",
        "cls"          : "Special",
        "duration"     : 3,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    },
    {
        "id"           : "r16",
        "resourceId"   : 11,
        "name"         : "Presentation",
        "iconCls"      : "b-fa b-fa-video",
        "startDate"    : "2025-12-01T13:00:00",
        "cls"          : "Special",
        "duration"     : 2,
        "durationUnit" : "h",
        "draggable"    : true,
        "resizable"    : true,
         "comments" : [],
         "test": ''
    }
])


    /**
     * @param {Event} record Event record
     * @param {TaskStore} eventStore Event store firing the event
     *
     * Reschedules the overlapping events if the button is pressed
     */
    const onEventStoreUpdate = useCallback(
        ({
            record,
            source: eventStore
        }) => {
            if (autoReschedule) {
                eventStore.rescheduleOverlappingTasks(record);
            }
        },
        [autoReschedule]
    );

    /**
     * @param {Event[]} records Array of Event records
     * @param {TaskStore} eventStore Event store firing the event
     *
     * Reschedules the overlapping events if the button is pressed
     */
    const onEventStoreAdd = useCallback(
        ({
            records,
            source: eventStore
        }) => {
            if (autoReschedule) {
                records.forEach(eventRecord =>
                    eventStore.rescheduleOverlappingTasks(eventRecord)
                );
            }
        },
        [autoReschedule]
    );

    useEffect(() => {
        Object.assign(eventStore, {
            onUpdate: onEventStoreUpdate,
            onAdd   : onEventStoreAdd
        });

        new Drag({
            grid        : grid.current.unplannedGrid,
            schedule    : scheduler.current.instance,
            constrain   : false,
            outerElement: grid.current.unplannedGrid.element
        });

        Toast.show({
            timeout: 3500,
            html   : 'Please note that this example uses the Bryntum Grid, which is licensed separately.'
        });
    }, [eventStore, onEventStoreAdd, onEventStoreUpdate]);

    const [eventMenuFeature] = useState({
            items: {
                // custom item with inline handler
                unassign: {
                    text  : 'Unassign',
                    icon  : 'b-fa b-fa-user-times',
                    weight: 200,
                    onItem: ({
                        eventRecord,
                        resourceRecord
                    }) =>
                        eventRecord.unassign(resourceRecord)
                }
            }
        }
    );

    function onDataChange({store, action, records, changes}){
    }

    const [listeners] = useState({
        renderEvent({ eventRecord, element }) {
            console.log("renderEvent fired!")
            console.log(eventRecord.comments)
            eventRecord.meta.notesTooltip = new Tooltip({
              constrainTo: null,
              floating: false,
              positioned: true,
              scrollAction: 'realign',
              style: {
                zIndex: 10,
                'font-size': 'initial',
              },
              html: `<div>${eventRecord.comments.data
                .map((x, index) => {
                  return `<div style="font-size: 1.2rem; line-height: 1.4rem">${x.text}</div>
                ${index + 1 < eventRecord.comments.data.length ? `<hr class="solid">` : ``}`;
                })
                .join('')}</div>`,
              autoClose: false,
            });
          eventRecord.meta.notesTooltip.render(element);
          eventRecord.meta.notesTooltip.showBy(element);
        }})
      

      
    return (
        <Fragment>
            <div className = "demo-toolbar align-right">
            <BryntumButton
                    toggleable = {true}
                    text = "Click here to test eventRender firing with changing string in EventModel"
                    tooltip = "Toggles whether to automatically reschedule overlapping tasks"
                    cls = "reschedule-button"
                    onClick = {() => {
                        const eventRecord = scheduler.current.instance.eventStore.getById('r4')
                        console.log(eventRecord)
                       const number = Math.random().toLocaleString()
                       console.log(number)
                       console.log(eventRecord.comments)
                        Object.assign(eventRecord, {comments: [{text: number}]})
                    }}/>
                                    <BryntumButton
                    toggleable = {true}
                    text = "Export"
                    tooltip = "Export"
                    cls = "export-button"
                    onClick = {() => {
                        scheduler.current.instance.features.pdfExport.showExportDialog()
                    }}/>
    <BryntumButton
                    toggleable = {true}
                    text = "Hide non working"
                    tooltip = "Hide non working"
                    cls = "export-button"
                    onClick = {() => {

scheduler.current.instance.timeAxis.filter((t) =>
          scheduler.current.instance.project.calendar.isWorkingTime(t.startDate, t.endDate)
        );}}/>
            </div>
            <div id = "main">
                <BryntumSchedulerPro
                    {...schedulerConfig}
                    ref = {scheduler}
                    stripeFeature = {true}
                    onDataChange={onDataChange}
                    timeRangesFeature = {true}
                    eventMenuFeature = {eventMenuFeature}
                    resources = {resources}
                    events = {events}
                    listeners={listeners}
                />
                <UnplannedGridComponent
                    ref = {grid}
                    eventStore = {eventStore}
                />
            </div>
        </Fragment>
    );
};

export default Content;
