import {  EventModel, Store } from '@bryntum/schedulerpro';

class Session extends EventModel {
    static get fields() {
      return [{ name: 'comments', type: 'store', storeClass: Store }];
    }
  }
  

export const schedulerConfig = {

    rowHeight        : 50,
    barMargin        : 4,
    eventColor       : 'indigo',

    columns: [
        {
            type          : 'resourceInfo',
            text          : 'Name',
            width         : 200,
        },
        {
            text    : 'Nbr tasks',
            editor  : false,
            renderer: data => `${data.record.events.length || ''}`,
            align   : 'center',
            width   : 100
        }
    ],

    project: {
        calendar: 'default',
        resourceStore: {
          syncDataOnLoad: true,
        },
        eventModelClass: Session,
        eventStore: {
          syncDataOnLoad: true,
          autoCommit: false,
        },
      },

      // PDF Export
  pdfExportFeature: {
    exportMask: 'Aufbereitung der Daten...',
    exportProgressMask: 'Konvertiere zu PDF', // This is not working!
    fileName: 'Planning',
    openInNewTab: true,
    repeatHeader: true,
    exportServer: 'http://localhost:8080',
    translateURLsToAbsolute: 'http://localhost:3000',
    clientURL: 'http://localhost:3000',

    keepPathName: false,
  },

    viewPreset: {
        base          : 'hourAndDay',
        columnLinesFor: 0,
        headers       : [
            {
                unit      : 'd',
                align     : 'center',
                dateFormat: 'ddd DD MMM'
            },
            {
                unit      : 'h',
                align     : 'center',
                dateFormat: 'HH'
            }
        ]
    },

    startDate: '2026-01-01',
    endDate  : '2026-01-31',

    calendars: [
      {
        id: 'default',
        name: '2-Schichtig (F+S)',
        unspecifiedTimeIsWorking: false,
        intervals: [
          {
            recurrentStartDate: 'at 06:00 except on Saturday and Sunday',
            recurrentEndDate: 'at 22:45 except on Saturday and Sunday',
            isWorking: true,
          },
        ],
        children: []
      }]
};
